@@ -17,7 +17,8 @@ def index(request):
         '%s/bakery.html' % constants.ADMIN_TEMPLATES_PATH,
         {
             'cache_icon': 'cog',
-            'ready': task.ready if task else True
+            'ready': task.ready if task else True,
+            'builds': TaskBuild.objects.all()[:5]
          },
     )
 
