@@ -8,9 +8,28 @@ from webspace.cms.blocks.common import \
     ButtonBlock, \
     EntryBlock, \
     ImageWithSizeBlock, \
-    PersonBlock
+    PersonBlock, \
+    IconTextBlock
 
 
+class StreamCard(blocks.StructBlock):
+    streams = blocks.StreamBlock(
+        [
+            ('svg', SvgWithSizeBlock()),
+            ('image', ImageWithSizeBlock()),
+            ('text', TextBlock()),
+            ('icon_text', IconTextBlock())
+        ],
+        required=False
+    )
+
+    class Meta:
+        template = '%s/common/cards/stream_card.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Stream Card"
+
+
+# FIXME: remove CustomCard and merge it with StreamCard
+
 class CustomCard(blocks.StructBlock):
     text = TextBlock()
     button = ButtonBlock()
@@ -25,7 +44,7 @@ class CustomCard(blocks.StructBlock):
     )
 
     class Meta:
-        template = '%s/common/custom_card.html' % constants.BLOCK_TEMPLATES_PATH
+        template = '%s/common/cards/custom_card.html' % constants.BLOCK_TEMPLATES_PATH
         label = "Custom Card"
 
 
@@ -46,7 +65,7 @@ class ReviewCard(blocks.StructBlock):
     )
 
     class Meta:
-        template = '%s/common/review_card.html' % constants.BLOCK_TEMPLATES_PATH
+        template = '%s/common/cards/review_card.html' % constants.BLOCK_TEMPLATES_PATH
         label = "Review Card"
 
 
@@ -60,6 +79,7 @@ class CardsEntry(EntryBlock):
             ('custom', CustomCard()),
             ('person', PersonCard()),
             ('review', ReviewCard()),
+            ('stream', StreamCard()),
         ],
         min_num=1
     )
